# osTIR

Open Source Translation Initiation Rates
Customized and updated version of RBS-Calculator-v1.0

Modifications begun on May 21, 2019.

Original source code and copyright information available here:
https://github.com/hsalis/Ribosome-Binding-Site-Calculator-v1.0